# Corr2cause

Causal inference is one of the hallmarks of human intelligence.

Corr2cause is a large-scale dataset of more than 400K samples, on which
seventeen existing LLMs are evaluated in the related paper.

Overall, Corr2cause contains 415,944 samples, with 18.57% in valid samples.
The average length of the premise is 424.11 tokens, and hypothesis 10.83 tokens.
The data is split into 411,452 training samples, 2,246 development and test
samples, respectively. Since the main purpose of the dataset is to benchmark the
performance of LLMs, the test and development sets have been prioritized to have
a comprehensive coverage over all sizes of graphs.